window.Gleam.initSearch([{"doc":"fmglee","title":"fmglee","content":"# FMglee\n\n[![Package Version](https://img.shields.io/hexpm/v/fmglee)](https://hex.pm/packages/fmglee)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/fmglee/)\n\nFMGlee is a simple string formatting library. It exposes two main APIs to format \nstrings, one driven by pipes, and the other more inline.\n\n```sh\ngleam add fmglee\n```\n```gleam\nimport fmglee as fmt\nimport gleeunit/should\n\nfmt.new(&quot;Number %d, float %f, string %s&quot;)\n|&gt; fmt.d(99)\n|&gt; fmt.f(12.9)\n|&gt; fmt.s(&quot;Hello!&quot;)\n|&gt; fmt.build\n|&gt; should.equal(&quot;Number 99, float 12.9, string Hello!&quot;)\n\n// OR\n\nfmt.fmt(&quot;Number %d, float %f, string %s&quot;, with: [fmt.D(99), fmt.F(12.9), fmt.S(&quot;Hello!&quot;)])\n|&gt; should.equal(&quot;Number 99, float 12.9, string Hello!&quot;)\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/fmglee&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"fmglee","title":"Fmt","content":"pub type Fmt {\n  S(String)\n  D(Int)\n  F(Float)\n}\n\nS(String)\n Wrap a `String` for use with `fmt(_, using: [..])`\n\nD(Int)\n Wrap an `Int` for use with `fmt(_, using: [..])`\n\nF(Float)\n Wrap a `Float` for use with `fmt(_, using: [..])`\n\nSynonyms:\nfmglee.Fmt\nfmglee Fmt","url":"fmglee.html#Fmt"},{"doc":"fmglee","title":"FmtError","content":"pub type FmtError {\n  IncorrectValueType\n  TooManyValues\n  NotEnoughValues\n}\n Errors returned by fmtglee\nIncorrectValueType\n The current value does not match the current placeholder.\n Returned when the order of `Fmt`s is not the same as the order\n of placeholders.\n\nTooManyValues\n Returned when there are more `Fmt`s than placeholders in the string.\n\nNotEnoughValues\n Returned when there are less `Fmt`s than placeholders in the string.\n\nSynonyms:\nfmglee.FmtError\nfmglee FmtError","url":"fmglee.html#FmtError"},{"doc":"fmglee","title":"Formatter","content":"pub type Formatter {\n  Formatter(s: String, v: List(Fmt))\n}\n\nFormatter(s: String, v: List(Fmt))\n Used to compile a format string using the pipeable methods.\n\nSynonyms:\nfmglee.Formatter\nfmglee Formatter","url":"fmglee.html#Formatter"},{"doc":"fmglee","title":"build","content":"pub fn build(formatter: Formatter) -&gt; String\n Compile a Formatter into a string. Panics where \n `try_build(formatter)` returns an `FmtError`.\nSynonyms:\nfmglee.build\nfmglee build","url":"fmglee.html#build"},{"doc":"fmglee","title":"d","content":"pub fn d(formatter: Formatter, d: Int) -&gt; Formatter\n Add an `Int` value to a `Formatter`.\nSynonyms:\nfmglee.d\nfmglee d","url":"fmglee.html#d"},{"doc":"fmglee","title":"f","content":"pub fn f(formatter: Formatter, f: Float) -&gt; Formatter\n Add a `Float` value to a `Formatter`.\nSynonyms:\nfmglee.f\nfmglee f","url":"fmglee.html#f"},{"doc":"fmglee","title":"fmt","content":"pub fn fmt(s: String, with v: List(Fmt)) -&gt; String\n Format a string and a list of `Fmt` values.\n Will panic where `try_fmt(s, v)` returns an\n `FmtError`.\nSynonyms:\nfmglee.fmt\nfmglee fmt","url":"fmglee.html#fmt"},{"doc":"fmglee","title":"new","content":"pub fn new(s: String) -&gt; Formatter\n Create a new `Formatter`.\n # Examples\n \n new(&quot;Hello, %s. You are %d years old.&quot;)\n |&gt; s(name)\n |&gt; d(age)\n |&gt; build\n |&gt; io.println\n \nSynonyms:\nfmglee.new\nfmglee new","url":"fmglee.html#new"},{"doc":"fmglee","title":"print","content":"pub fn print(s: String, with v: List(Fmt)) -&gt; Nil\n Compile the format string and print the output.\n Panics if `fmt(s, v)` would panic with the\n provided arguments.\nSynonyms:\nfmglee.print\nfmglee print","url":"fmglee.html#print"},{"doc":"fmglee","title":"printf","content":"pub fn printf(formatter: Formatter) -&gt; Nil\n Print the output of a compiled `Formatter`.\n Panics if the `Formatter` is invalid.\nSynonyms:\nfmglee.printf\nfmglee printf","url":"fmglee.html#printf"},{"doc":"fmglee","title":"println","content":"pub fn println(s: String, with v: List(Fmt)) -&gt; Nil\n Compile the format string and print the output\n with a newline. Panics if `fmt(s, v)` would\n panic with the provided arguments.\nSynonyms:\nfmglee.println\nfmglee println","url":"fmglee.html#println"},{"doc":"fmglee","title":"printlnf","content":"pub fn printlnf(formatter: Formatter) -&gt; Nil\n Print the output of a compiled `Formatter`\n with a newline. Panics if the `Formatter`\n is invalid.\nSynonyms:\nfmglee.printlnf\nfmglee printlnf","url":"fmglee.html#printlnf"},{"doc":"fmglee","title":"s","content":"pub fn s(formatter: Formatter, s: String) -&gt; Formatter\n Add a `String` value to a `Formatter`.\nSynonyms:\nfmglee.s\nfmglee s","url":"fmglee.html#s"},{"doc":"fmglee","title":"try_build","content":"pub fn try_build(\n  formatter: Formatter,\n) -&gt; Result(String, FmtError)\n Compile a `Formatter` into a string. Errors when the\n number of provided values does not match the number\n of placeholders, or if an invalid type was provided\n for a placeholder.\nSynonyms:\nfmglee.try_build\nfmglee try_build","url":"fmglee.html#try_build"},{"doc":"fmglee","title":"try_fmt","content":"pub fn try_fmt(\n  s: String,\n  with v: List(Fmt),\n) -&gt; Result(String, FmtError)\n Format a string and a list of `Fmt` values. Substitutes\n placeholders from left to right with values in the\n list of Fmt. Errors if there is a type missmatch between\n the placeholder and the value, or if the number of placeholders\n does not match the number of values given.\nSynonyms:\nfmglee.try_fmt\nfmglee try_fmt","url":"fmglee.html#try_fmt"},{"doc":"fmglee","title":"write","content":"pub fn write(\n  s: String,\n  with v: List(Fmt),\n  using writer: fn(String) -&gt; Nil,\n) -&gt; Nil\n Write a string and list of `Fmt` to the provided `Writer`.\nSynonyms:\nfmglee.write\nfmglee write","url":"fmglee.html#write"},{"doc":"fmglee","title":"writef","content":"pub fn writef(\n  formatter: Formatter,\n  using writer: fn(String) -&gt; Nil,\n) -&gt; Nil\n Write a `Formatter` to the provided writer. The `Formatter`\n will be built using `build` which will panic if the\n formatter is invalid.\nSynonyms:\nfmglee.writef\nfmglee writef","url":"fmglee.html#writef"},{"doc":"fmglee","title":"fmglee","content":" # fmglee\n\n A string formatting library for gleam.\n\n Valid format specifiers are\n - %s - String\n - %d - Int\n - %f - Float\n\n Examples\n ```gleam\n import fmglee as fmt\n import gleeunit/should\n \n fmt.new(&quot;Number %d, float %f, string %s&quot;)\n |&gt; fmt.d(99)\n |&gt; fmt.f(12.9)\n |&gt; fmt.s(&quot;Hello!&quot;)\n |&gt; fmt.build\n |&gt; should.equal(&quot;Number 99, float 12.9, string Hello!&quot;)\n ```\n ```gleam\n fmt.fmt(&quot;Number %d, float %f, string %s&quot;, with: [fmt.D(99), fmt.F(12.9), fmt.S(&quot;Hello!&quot;)])\n |&gt; should.equal(&quot;Number 99, float 12.9, string Hello!&quot;)\n ```","url":"fmglee.html"}]);